Int (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.Program_prelude_.Int)

`type t = int`
`val (+) : t -> t -> t`
`val (-) : t -> t -> t`
`val (~-) : t -> t`
`val (*) : t -> t -> t`
`val (/) : t -> t -> t`
`val (mod) : t -> t -> t`
`val (<) : t -> t -> bool`
`val (<=) : t -> t -> bool`
`val (>) : t -> t -> bool`
`val (>=) : t -> t -> bool`
`val min : t -> t -> t`
`val max : t -> t -> t`
`val incr : t Stdlib.ref -> unit`
`val decr : t Stdlib.ref -> unit`
`val succ : t -> t`
`val pred : t -> t`
`val of_int : int -> t`